==> wifieye_0.2.1.orig.tar.gz: wifieye-0.2.1/src/win.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: win.py 2226 2010-02-11 23:44:56Z v13 $

from PyQt4 import QtGui
from PyQt4.QtCore import SIGNAL, Qt

import sys

import graph, wifi
#import portrait

win=None

class MainWin(QtGui.QMainWindow):
    def setupUi(self):
	self.centralwidget=QtGui.QWidget(self)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graph.WifiGraph()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	self.l1=QtGui.QHBoxLayout()
	self.buttonRefresh=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonRefresh)
	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	self.setCentralWidget(self.centralwidget)

	self.retranslateUi()

	self.connect(self.buttonRefresh, SIGNAL('clicked()'), self.slotRefresh)

    def retranslateUi(self):
	self.setWindowTitle("Wifi Eye")
	self.buttonRefresh.setText("Refresh")

    def setData(self, dt):
	self.graph.setData(dt)

    def slotRefresh(self):
	dt=wifi.scan()
	self.setData(dt)
	self.repaint()


def init():
    global app, win, por
    app=QtGui.QApplication(sys.argv)
    #app.setAttribute(Qt.WA_Maemo5ForceLandscapeOrientation, True);
#    win0=QtGui.QMainWindow()
    win=MainWin()
    #por=portrait.FremantleRotation("wifieye", win, '1.0')

    win.setupUi()

def doit(dt):
    global app, win
    win.setData(dt)
    win.show()
    #label=QtGui.QLabel("test")

    #label.show()
    sys.exit(app.exec_())

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:

==> wifieye_0.3.0.orig.tar.gz: wifieye-0.3.0/src/win.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: win.py 2238 2010-02-12 19:29:16Z v13 $

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import SIGNAL, Qt

import sys

import graphchannels, graphtime, wifi, data
#import portrait

win=None

class MainWin(QtGui.QMainWindow):
#    def __init__(self):
#	QtGui.QMainWindow(self)
#	pass

    def setupUiChannels(self):
	self.centralwidget=QtGui.QWidget(self)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphchannels.GraphChannels()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	self.l1=QtGui.QHBoxLayout()
	self.buttonTimeview=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonTimeview)
	self.buttonRefresh=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonRefresh)
	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	self.setCentralWidget(self.centralwidget)

	self.retranslateUiChannels()

	self.connect(self.buttonRefresh, SIGNAL('clicked()'), self.slotRefresh)
	self.connect(self.buttonTimeview, SIGNAL('clicked()'),
		self.slotTimeview)

	self.what='channels'

	self.slotRefresh()

    def setupUiTime(self):
	self.centralwidget=QtGui.QWidget(self)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphtime.GraphTime()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	self.l1=QtGui.QHBoxLayout()
	self.buttonChannelview=QtGui.QPushButton(self.centralwidget)
	self.l1.addWidget(self.buttonChannelview)
	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	self.setCentralWidget(self.centralwidget)

	self.retranslateUiTime()

	self.connect(self.buttonChannelview, SIGNAL('clicked()'),
		self.slotChannelview)

	self.timer=QtCore.QTimer(self.centralwidget)
	self.connect(self.timer, SIGNAL('timeout()'), self.timerGetData)
	self.timer.start(1000)

	self.what='time'

    def setupUi(self):
	self.graph=None
	self.setupUiChannels()
	#self.setupUiTime()

    def retranslateUiChannels(self):
	self.setWindowTitle("Wifi Eye")
	self.buttonRefresh.setText("Refresh")
	self.buttonTimeview.setText("Time Graph")

    def retranslateUiTime(self):
	self.setWindowTitle("Wifi Eye")
	#self.buttonRefresh.setText("Refresh")
	self.buttonChannelview.setText("Channels")

    def slotRefresh(self):
	dt=wifi.scan()
	self.graph.setData(dt)
	self.repaint()

    def slotTimeview(self):
	self.setupUiTime()

    def slotChannelview(self):
	self.setupUiChannels()
	self.timer=None

    def timerGetData(self):
	#print "timer"
	dt=wifi.scan()
	data.add(dt)
	self.repaint()

def init():
    global app, win, por
    app=QtGui.QApplication(sys.argv)
    #app.setAttribute(Qt.WA_Maemo5ForceLandscapeOrientation, True);
#    win0=QtGui.QMainWindow()
    win=MainWin()
    #por=portrait.FremantleRotation("wifieye", win, '1.0')

    win.setupUi()

def doit(dt):
    global app, win
#    win.setData(dt)
    win.show()
    #label=QtGui.QLabel("test")

    #label.show()
    sys.exit(app.exec_())

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:
